#!/usr/bin/python
# 
# Copyright (C) 2009, Intel Corporation.
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.  
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307 USA.
#
# Authors:
#              Wei, Zhang <wei.z.zhang@intel.com>
#

import sys
import os
import re

sys.path.append('../../tetj/')
from tetj import *

sys.path.append('../utils/')
from shell_exec import *

info = ""

#=======================================
# Print + Journal
def __P(log):

    global info

    sys.stdout.write(log)
    info += log

#=======================================
# Parse package version from one string
def __parse_pkg_version(pkg_ver_str):
    pkg_ver_str = "\n" + pkg_ver_str
    res = re.findall(r'[-:\s]([\d\.-]+\d)', pkg_ver_str)
    
    if len(res) != 0:
        return res[0]
    else:
        return None

#=======================================
# Get version requirement
def __get_req_ver(obj):
    return shell_exec1("cat %s/data/ver_req | grep %s | awk '{print $2}'" % (sys.path[0], obj))


#=======================================
# Get version in system
def __get_cur_ver(obj):
    return __parse_pkg_version(shell_exec1("%s --version 2>/dev/null" % obj));

#=======================================
# compare version
def compare_ver(cur_ver, req_ver, is_above_req):
    # not allowed None
    if cur_ver == None or req_ver == None:
        return False

    # deal with '-'
    cur_ver = cur_ver.replace('-', '.')
    req_ver = req_ver.replace('-', '.')

    # split 
    cur_vers = cur_ver.split('.')
    req_vers = req_ver.split('.')
    
    # Convert list members to integer type
    cur_vers_int = [ int(num) for num in cur_vers ]
    req_vers_int = [ int(num) for num in req_vers ]

    # Compare 2 lists
    if is_above_req:
	return cur_vers_int >= req_vers_int
    else:
	return cur_vers_int == req_vers_int

#=======================================
# pkg_mgr_version
def pkg_mgr_version_check():

    global info
    info = ""

    try:
        # get current
        vc1 = __get_cur_ver("rpm")
        vc2 = __get_cur_ver("dpkg")
    
        # get require
        vr1 = __get_req_ver("rpm")
        vr2 = __get_req_ver("dpkg")

        # compare
        c1 = compare_ver(vc1, vr1, True);
        c2 = compare_ver(vc2, vr2, True);

        # get info
        __P("rpm check(%s):   current version| %s      required version| %s\n" %(c1, vc1, vr1))
        __P("dpkg check(%s):  current version| %s      required version| %s\n" %(c2, vc2, vr2))

        res = (c1 or c2)
    
        tetj_res = TETJ_FAIL
        if res:
            tetj_res = TETJ_PASS
        
        return [tetj_res, info]
    
    except Exception, Ex:
        print Ex.__str__
        return [TETJ_FAIL, info]   
    
#=======================================
# repos_mgr_version
def repos_mgr_version_check():

    global info
    info = ""

    try:
        # get current
        vc1 = __get_cur_ver("yum")
	vc2 = __get_cur_ver("zypper")
        vc3 = __get_cur_ver("apt-get")
    
        # get require
        vr1 = __get_req_ver("yum")
        vr2 = __get_req_ver("zypper")
        vr3 = __get_req_ver("apt")

        # compare
        c1 = compare_ver(vc1, vr1, True);
        c2 = compare_ver(vc2, vr2, True);
        c3 = compare_ver(vc3, vr3, True);

        # get info
        __P("yum check(%s):   current version| %s      required version| %s\n" %(c1, vc1, vr1))
        __P("zypper check(%s):   current version| %s      required version| %s\n" %(c2, vc2, vr2))
        __P("apt check(%s):   current version| %s      required version| %s\n" %(c3, vc3, vr3))

        res = (c1 or c2 or c3)
    
        tetj_res = TETJ_FAIL
        if res:
            tetj_res = TETJ_PASS
        
        return [tetj_res, info]
    
    except Exception, Ex:
        print Ex.__str__
        return [TETJ_FAIL, info]   
    
#=======================================
# test
if __name__ == '__main__':
    p = pkg_mgr_version_check()
    print "package manager checking result:%s" % RESULT_CODES[p[0]]
    p = repos_mgr_version_check()
    print "repository manager checking result:%s" % RESULT_CODES[p[0]]
