#!/usr/bin/python
# 
# Copyright (C) 2009, Intel Corporation.
# 
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.  
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307 USA.
#
# Authors:
#              Wei, Zhang <wei.z.zhang@intel.com>
#

import sys
import os
import re

sys.path.append('../../tetj/')
from tetj import *

sys.path.append('../utils/')
from shell_exec import *

info = ""

#=======================================
# Print + Journal
def __P(log):

    global info

    sys.stdout.write(log)
    info += log

#=======================================
# check install files
def check_install_files(path):

    try:
	files = set(shell_exec1("ls %s"%path).split())

	# if Makefile and description-pak are not exist, throw exception
	files.remove("Makefile")

	# check file
	sfiles = [ int(f) for f in files ]
	tfiles = range(100)
	sfiles.sort()
	tfiles.sort()

	if sfiles == tfiles:
		return True

    except Exception, Ex:
        print Ex.__str__
        return False 

#=======================================
# rpm package install check
def rpm_simple_install_check():

    global info

    __P("[simple install rpm package]\n")    

    try:
    	ret = False

	# remove old
	res = shell_exec3("sudo rpm -q example")
	if res[0] == 0:
		shell_exec2("sudo rpm -e example;")
	
	# install
	res = shell_exec3("sudo rpm -ivh %s/data/example-1.0.0-1*.rpm --nodeps" %sys.path[0]);__P(res[1]+"\n")
	if res[0] == 0:
		
		# check files
		if check_install_files("/tmp/rpm_test_tmp/example"):
			__P("install example-1.0.0-1*.rpm and check install files pass\n")	
        		ret = True
		else:
			__P("check install files fail\n")
	else:

		__P("install example-1.0.0-1*.rpm fail\n")	

	# remove 	
	shell_exec2("sudo rpm -e example;")

        return ret
    
    except Exception, Ex:
        print Ex.__str__
        return False
    
#=======================================
# deb package install check
def deb_simple_install_check():

    global info

    __P("[simple install deb package]\n")    

    try:
    	ret = False

	# remove old
	res = shell_exec3("sudo dpkg -l example")
	if res[0] == 0:
		shell_exec2("sudo dpkg -r example;")
	
	# install
	res = shell_exec3("sudo dpkg -i %s/data/example-1.0.0-1*.deb" %sys.path[0]);__P(res[1])
	if res[0] == 0:
		
		# check files
		if check_install_files("/tmp/deb_test_tmp/example"):
			__P("install example-1.0.0-1*.deb and check install files pass\n")	
        		ret = True
		else:
			__P("check install files fail\n")
	else:

		__P("install example-1.0.0-1*.deb fail\n")	

	# remove 	
	shell_exec2("sudo dpkg -r example;")

        return ret
    
    except Exception, Ex:
        print Ex.__str__
        return False

#=======================================
# rpm or deb testing should pass one at least
def pkg_simple_install_check():

    is_deb_os = False
    if os.path.exists("/etc/debian_version"):
        is_deb_os = True
    
    check_install_func = None
    
    if is_deb_os:
        # check existance of package
        __P ("[check existance of package...]\n")
        if  0 == shell_exec3("ls %s/data/example-1.0.0-1*.deb" %sys.path[0])[0]:
            __P ("example-1.0.0-1.*.deb found\n")
            
            check_install_func = deb_simple_install_check
        else:
            __P ("skip the install checking since example package not found\n")
    	    return [TETJ_UNTESTED, info]
    
    else:
        # check existance of package
        __P ("[check existance of package...]\n")
        if  0 == shell_exec3("ls %s/data/example-1.0.0-1*.rpm" %sys.path[0])[0]:
            __P ("example-1.0.0-1.*.rpm found\n")
            
            check_install_func = rpm_simple_install_check
        else:
            __P ("skip the install checking since example package not found\n")
    	    return [TETJ_UNTESTED, info]

    __P ("[simple check install package...]\n")
    if check_install_func and check_install_func():
        __P ("pkg_simple_install PASS\n")
	return [TETJ_PASS, info]
    else:
        __P ("pkg_simple_install FAIL\n")
	return [TETJ_FAIL, info]

#=======================================
# test
if __name__ == '__main__':
    p = pkg_simple_install_check()
    print "result:%s" % RESULT_CODES[p[0]]
